@@ -3,8 +3,10 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
+from swagger_client.api.analysis_api import AnalysisApi
 from swagger_client.api.boards_api import BoardsApi
 from swagger_client.api.datasets_api import DatasetsApi
+from swagger_client.api.insights_api import InsightsApi
 from swagger_client.api.projects_api import ProjectsApi
 from swagger_client.api.teams_api import TeamsApi
 from swagger_client.api.users_api import UsersApi
